
/* Generated data (by glib-mkenums) */

#ifndef __LIBEMPATHY_ENUM_TYPES_H__
#define __LIBEMPATHY_ENUM_TYPES_H__ 1

#include <glib-object.h>

G_BEGIN_DECLS

#include <libempathy/empathy-contact.h>
#define EMPATHY_TYPE_CAPABILITIES empathy_capabilities_get_type()
GType empathy_capabilities_get_type (void);
#include <libempathy/empathy-debug.h>
#define EMPATHY_TYPE_DEBUG_FLAGS empathy_debug_flags_get_type()
GType empathy_debug_flags_get_type (void);
#include <libempathy/empathy-dispatch-operation.h>
#define EMPATHY_TYPE_DISPATCH_OPERATION_STATE empathy_dispatch_operation_state_get_type()
GType empathy_dispatch_operation_state_get_type (void);
#include <libempathy/empathy-tp-call.h>
#define EMPATHY_TYPE_TP_CALL_STATUS empathy_tp_call_status_get_type()
GType empathy_tp_call_status_get_type (void);
G_END_DECLS

#endif /* __LIBEMPATHY_ENUM_TYPES_H__ */

/* Generated data ends here */

